@@ -101,11 +101,15 @@ if python_prefix_matches and python_version_matches:
 
     # 探针初始化
     print("121212")
-    from fast_tracker import agent, config
+    try:
+        print("11111111")
+        from fast_tracker import agent, config
 
-    print("888")
-    # config.init(collector="127.0.0.1:8111", service="as you wish")
-    config.init(collector="fluent:5140", service="as you wish")
-    print("999")
-    agent.start()
-    print("101010")
+        print("888")
+        # config.init(collector="127.0.0.1:8111", service="as you wish")
+        config.init(collector="fluent:5140", service="as you wish")
+        print("999")
+        agent.start()
+        print("101010")
+    except BaseException as e:
+        print("发生错误了，错误信息是", e)
